@@ -19,28 +19,29 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "previewitemdelegate.moc"
+#include "previewitemdelegate.h"
 #include <config-gwenview.h>
 
 // Qt
 #include <QHash>
 #include <QHBoxLayout>
-#include <QHelpEvent>
-#include <QLabel>
 #include <QPainter>
 #include <QPainterPath>
 #include <QParallelAnimationGroup>
 #include <QPointer>
 #include <QPropertyAnimation>
 #include <QSequentialAnimationGroup>
+#include <QUrl>
+#include <QEvent>
+#include <QHoverEvent>
+#include <QDateTime>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
 #include <KDirModel>
 #include <KGlobalSettings>
-#include <KLineEdit>
-#include <KLocale>
-#include <KUrl>
+#include <KIconLoader>
+
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
 #include <kratingpainter.h>
 #endif
@@ -99,7 +100,7 @@ static KFileItem fileItemForIndex(const QModelIndex& index)
     return qvariant_cast<KFileItem>(data);
 }
 
-static KUrl urlForIndex(const QModelIndex& index)
+static QUrl urlForIndex(const QModelIndex& index)
 {
     KFileItem item = fileItemForIndex(index);
     return item.url();
@@ -400,8 +401,8 @@ struct PreviewItemDelegatePrivate
         const bool isDirOrArchive = ArchiveUtils::fileItemIsDirOrArchive(fileItem);
         if (mDetails & PreviewItemDelegate::DateDetail) {
             if (!ArchiveUtils::fileItemIsDirOrArchive(fileItem)) {
-                const KDateTime dt = TimeUtils::dateTimeForFileItem(fileItem);
-                const QString text = KGlobal::locale()->formatDateTime(dt);
+                const QDateTime dt = TimeUtils::dateTimeForFileItem(fileItem);
+                const QString text = QLocale().toString(dt, QLocale::ShortFormat);
                 elided |= isTextElided(text);
                 textList << text;
             }
@@ -485,7 +486,7 @@ struct PreviewItemDelegatePrivate
         anim->addAnimation(fadeOut);
         mToolTipAnimation.reset(anim);
         mToolTipAnimation->start();
-        QObject::connect(anim, SIGNAL(finished()), mToolTip, SLOT(deleteLater()));
+        QObject::connect(anim, &QSequentialAnimationGroup::finished, mToolTip.data(), &ToolTipWidget::deleteLater);
     }
 
     int itemWidth() const
@@ -610,20 +611,16 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
     d->mContextBar->hide();
 
     d->mToggleSelectionButton = new ContextBarButton("list-add");
-    connect(d->mToggleSelectionButton, SIGNAL(clicked()),
-            SLOT(slotToggleSelectionClicked()));
+    connect(d->mToggleSelectionButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotToggleSelectionClicked);
 
     d->mFullScreenButton = new ContextBarButton("view-fullscreen");
-    connect(d->mFullScreenButton, SIGNAL(clicked()),
-            SLOT(slotFullScreenClicked()));
+    connect(d->mFullScreenButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotFullScreenClicked);
 
     d->mRotateLeftButton = new ContextBarButton("object-rotate-left");
-    connect(d->mRotateLeftButton, SIGNAL(clicked()),
-            SLOT(slotRotateLeftClicked()));
+    connect(d->mRotateLeftButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotRotateLeftClicked);
 
     d->mRotateRightButton = new ContextBarButton("object-rotate-right");
-    connect(d->mRotateRightButton, SIGNAL(clicked()),
-            SLOT(slotRotateRightClicked()));
+    connect(d->mRotateRightButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotRotateRightClicked);
 
     QHBoxLayout* layout = new QHBoxLayout(d->mContextBar);
     layout->setMargin(2);
@@ -636,8 +633,7 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
     // Save button
     d->mSaveButton = new ContextBarButton("document-save", d->mView->viewport());
     d->mSaveButton->hide();
-    connect(d->mSaveButton, SIGNAL(clicked()),
-            SLOT(slotSaveClicked()));
+    connect(d->mSaveButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotSaveClicked);
 }
 
 PreviewItemDelegate::~PreviewItemDelegate()
@@ -792,8 +788,8 @@ void PreviewItemDelegate::paint(QPainter * painter, const QStyleOptionViewItem &
     }
 
     if (!isDirOrArchive && (d->mDetails & PreviewItemDelegate::DateDetail)) {
-        const KDateTime dt = TimeUtils::dateTimeForFileItem(fileItem);
-        d->drawText(painter, textRect, fgColor, KGlobal::locale()->formatDateTime(dt));
+        const QDateTime dt = TimeUtils::dateTimeForFileItem(fileItem);
+        d->drawText(painter, textRect, fgColor, QLocale().toString(dt, QLocale::ShortFormat));
         textRect.moveTop(textRect.bottom());
     }
 
